# AI Capabilities
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/ai-capabilities#overview)
  * [Benefits](https://help.sap.com/docs/leanix/ea/ai-capabilities#benefits)
  * [Transparency and Governance of AI Features](https://help.sap.com/docs/leanix/ea/ai-capabilities#transparency-and-governance-of-ai-features)
  * [Base AI Capabilities](https://help.sap.com/docs/leanix/ea/ai-capabilities#base-ai-capabilities)
  * [Inventory Builder](https://help.sap.com/docs/leanix/ea/ai-capabilities#inventory-builder)
  * [Joule in SAP LeanIX](https://help.sap.com/docs/leanix/ea/ai-capabilities#joule-in-sap-leanix)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/ai-capabilities#prerequisites)
  * [Activating AI Capabilities](https://help.sap.com/docs/leanix/ea/ai-capabilities#activating-ai-capabilities)


View all
AI capabilities in SAP LeanIX automate documentation tasks, offer contextual insights, and support natural language queries to streamline enterprise architecture management. Use it to boost efficiency, reduce manual work, and maintain compliance with data privacy and ethical standards.
